==========
Motivation
==========

CLARITE was created to provide an easy-to-use tool for analysis of traits and exposures.

It exists as both a python package (for integration into scripts and/or other packages) and as a command line program.
